@@ -12,3 +12,11 @@ def SYSTEM_EV_PHONE_DIALING(): pass
 
 def SYSTEM_EV_PHONE_HANGUP(): pass
 
+def SYSTEM_EV_NORMAL_MODE(): pass
+
+def SYSTEM_EV_OFFLINE_MODE(): pass
+
+def POLICY_EV_FMRADIO_DISALLOWED(): pass
+
+def POLICY_EV_FMRADIO_ALLOWED(): pass
+
