@@ -22,14 +22,19 @@ class ButtonItem(Item):
         if (is_new):
             pmap.fill_area(0, 0, w, h, theme.color_mb_background)
 
-            pmap.draw_frame(theme.mb_button_1, 4, 4, w - 8, h - 8,
+            if (self.is_marked()):
+                btn_pbuf = theme.mb_button_2
+            else:
+                btn_pbuf = theme.mb_button_1
+
+            pmap.draw_frame(btn_pbuf, 4, 4, w - 8, h - 8,
                             pmap.TOP | pmap.BOTTOM |
                             pmap.LEFT | pmap.RIGHT)
 
             pmap.set_clip_rect(5, 5, w - 10, h - 10)
-            pmap.draw_centered_text(self.__label, theme.font_mb_tiny,
+            pmap.draw_centered_text(self.__label, theme.font_mb_plain,
                                     0, 0, w, h,
-                                    theme.color_mb_listitem_text)
+                                    theme.color_ui_button_text)
             pmap.set_clip_rect()
         #end if
         
