@@ -20,10 +20,7 @@ class ThumbableGridView(GridView):
     
         # the associated slider
         self.__slider = None
-        
-        # whether we have drag-sort enabled
-        self.__has_drag_sort = False
-        
+               
         # whether the letter is visible
         self.__letter_visible = False
         
@@ -41,6 +38,7 @@ class ThumbableGridView(GridView):
         self.add_overlay_renderer(self.__render_letter)
         
         self.__kscr = KineticScroller(self)
+        self.__kscr.connect_scrolling_started(self.__on_scrolling_started)
         self.__kscr.connect_clicked(self.__on_clicked)
         self.__kscr.connect_tap_and_hold(self.__on_tap_and_hold)
 
@@ -58,7 +56,7 @@ class ThumbableGridView(GridView):
             letter = item.get_letter()
             
             if (letter):
-                tw, th = text_extents(letter, theme.font_mb_list_letter)
+                tw, th = text_extents(letter, theme.font_list_letter)
                 tx = (w - tw) / 2
                 ty = (h - th) / 2
                 border_width = 10
@@ -68,41 +66,61 @@ class ThumbableGridView(GridView):
                 by = (h - bh) / 2
                 
                 screen.fill_area(bx, by, bw, bh,
-                                 theme.color_mb_list_letter_background)
-                screen.draw_text(letter, theme.font_mb_list_letter, tx, ty,
-                                 theme.color_mb_list_letter)
+                                 theme.color_list_letter_background)
+                screen.draw_text(letter, theme.font_list_letter, tx, ty,
+                                 theme.color_list_letter)
             #end if
         #end if
 
 
+    def __on_scrolling_started(self):
+    
+        csr = self.get_cursor()
+        if (csr != -1):
+            self.set_cursor(-1)
+            self.invalidate_item(csr)
+            self.render()
+
+
     def __on_clicked(self, px, py):
     
-        if (not self.__has_drag_sort):
-            idx = self.get_item_at(px, py)
-            x, y = self.get_position_of_item(idx)
-            item = self.get_item(idx)
-            item.click_at(px - x, py - y)
-        #end if
+        idx = self.get_item_at(px, py)
+        x, y = self.get_position_of_item(idx)
+        item = self.get_item(idx)
+        item.click_at(px - x, py - y)
 
         
     def __on_tap_and_hold(self, px, py):
 
-        if (not self.__has_drag_sort):
+        if (not self.has_floating_item()):
             idx = self.get_item_at(px, py)
             x, y = self.get_position_of_item(idx)
             item = self.get_item(idx)
             item.tap_and_hold(px - x, py - y)
+
+            csr = self.get_cursor()
+            if (csr != -1):
+                self.set_cursor(-1)
+                self.invalidate_item(csr)
+                self.render()
+            #end if
         #end if
 
 
     def __on_press_button(self, px, py):
     
-        if (self.__has_drag_sort):
-            idx = self.get_item_at(px, py)
-            self.float_item(idx, px, py)
+        idx = self.get_item_at(px, py)
+        item = self.get_item(idx)
+        w, h = self.get_size()
+        
+        if (px > w - 80 and item.is_draggable()):
+            # handle drag-sorting
+            self.float_item(idx, px - w, py)
+            self.__kscr.set_enabled(False)
             self.invalidate()
 
         else:
+            # handle clicking
             idx = self.get_item_at(px, py)
             self.set_cursor(idx)
             self.invalidate_item(idx)
@@ -119,6 +137,7 @@ class ThumbableGridView(GridView):
         
         if (self.has_floating_item()):
             self.float_item(-1)
+            self.__kscr.set_enabled(True)
             self.invalidate()
 
         self.render()
@@ -132,13 +151,16 @@ class ThumbableGridView(GridView):
     def __on_pointer_moved(self, px, py):
     
         if (self.has_floating_item()):
+            # handle drag-sorting
             floating_idx = self.get_floating_item()
             new_idx = self.get_item_at(px, py)
-            self.shift_item(floating_idx, new_idx - floating_idx)
+            if (0 <= new_idx < self.count_items()):
+                w, h = self.get_size()
+                self.shift_item(floating_idx, new_idx - floating_idx)
 
-            self.float_item(new_idx, px, py)
-            self.invalidate()
-            self.render()
+                self.float_item(new_idx, px - w, py)
+                self.invalidate()
+                self.render()
             
             if (self.__autoscroll_handler):
                 gobject.source_remove(self.__autoscroll_handler)
@@ -148,17 +170,12 @@ class ThumbableGridView(GridView):
             if (py < 80):
                 self.__autoscroll_handler = gobject.timeout_add(
                                                  50, self.__do_autoscroll, -30)
-                #self.move(0, -30)
+
             elif (py > h - 80):
                 self.__autoscroll_handler = gobject.timeout_add(
                                                  50, self.__do_autoscroll, 30)
-                #self.move(0, 60)
 
-        else:
-            csr = self.get_cursor()
-            if (csr != -1):
-                self.set_cursor(-1)
-                self.invalidate_item(csr)
+        #end if
 
 
         
@@ -184,6 +201,11 @@ class ThumbableGridView(GridView):
         return True
 
 
+    def stop_scrolling(self):
+    
+        self.__kscr.stop_scrolling()
+
+
     def move(self, dx, dy):
     
         self.__letter_visible = True
@@ -196,11 +218,7 @@ class ThumbableGridView(GridView):
             self.__kscr.stop_scrolling()
         
         # position slider
-        if (self.__slider):
-            w, h = self.get_size()
-            total_w, total_h = self.get_total_size()
-            percent = self.get_offset() / float(total_h - h)
-            self.__slider.set_value(1.0 - percent)
+        self.__update_slider()
 
         if (self.__letter_timeout_handler):
             gobject.source_remove(self.__letter_timeout_handler)
@@ -209,6 +227,31 @@ class ThumbableGridView(GridView):
 
         return (dx, dy)
 
+
+    def switch_item_set(self, s):
+    
+        GridView.switch_item_set(self, s)
+        self.__update_slider()            
+
+    def clear_items(self):
+    
+        GridView.clear_items(self)
+        self.__update_slider()
+
+
+    def __update_slider(self):
+
+        if (self.__slider):
+            w, h = self.get_size()
+            total_w, total_h = self.get_total_size()
+            if (total_h <= h):
+                percent = 0.0
+            else:
+                percent = self.get_offset() / float(total_h - h)
+            self.__slider.set_value(1.0 - percent)
+        #end if    
+    
+
         
     def associate_with_slider(self, slider):
         """
@@ -231,9 +274,3 @@ class ThumbableGridView(GridView):
         
         print "connect_item_menu_opened"
 
-        
-    def set_drag_sort_enabled(self, v):
-    
-        self.__has_drag_sort = v
-        self.__kscr.set_enabled(not v)
-
